Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(380)

Unified Diff: dart/frog/presubmit.py

Issue 8497011: Parse formal parameters. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: dart/frog/presubmit.py
diff --git a/dart/frog/presubmit.py b/dart/frog/presubmit.py
index e883156fba3496ac2f063720b82887637ed3947c..4ab5ce9f59ffa86452e85d47f6ac0fd9870432b1 100755
--- a/dart/frog/presubmit.py
+++ b/dart/frog/presubmit.py
@@ -51,7 +51,7 @@ def main(args):
"""Adds ANSI escape-code for bold-face"""
return "\033[1m%s\033[0m" % s
# VM Checked, produces checked
print 'Started'
start = time.time()
RunCommand('./frog.py',
@@ -59,6 +59,16 @@ def main(args):
'--', '--enable_type_checks', '--out=frogsh', 'frog.dart')
elapsed = time.time() - start
print 'Compiling on Dart VM took %s seconds %s' % (b(elapsed),
kasperl 2011/11/08 12:32:49 Maybe throw 'in checked mode + compile all' in a l
ahe 2011/11/08 12:40:31 Done.
+ b('in checked mode '
+ '+ compile all'))
+
+ # VM Checked, produces checked
+ start = time.time()
+ RunCommand('./frog.py',
+ '--vm_flags=--enable_type_checks --enable_asserts',
+ '--', '--enable_type_checks', '--out=frogsh', 'frog.dart')
+ elapsed = time.time() - start
+ print 'Compiling on Dart VM took %s seconds %s' % (b(elapsed),
b('in checked mode'))
# VM Normal, produces checked
@@ -51,7 +51,7 @@ def main(args):
"""Adds ANSI escape-code for bold-face"""
return "\033[1m%s\033[0m" % s
- # VM Checked, produces checked
+ # VM Checked/CompileAll, produces checked
print 'Started'
start = time.time()

Powered by Google App Engine
This is Rietveld 408576698